from qtstrap import QColor


class colors:
    navy = '#001f3f'
    blue = '#0074D9'
    aqua = '#7FDBFF'
    teal = '#39CCCC'
    olive = '#3D9970'
    green = '#2ECC40'
    lime = '#01FF70'
    yellow = '#FFDC00'
    orange = '#FF851B'
    red = '#FF4136'
    maroon = '#85144b'
    fuchsia = '#F012BE'
    purple = '#B10DC9'
    black = '#111111'
    grey = '#AAAAAA'
    gray = '#AAAAAA'
    silver = '#DDDDDD'
    white = '#FFFFFF'


class qcolors:
    navy = QColor(colors.navy)
    blue = QColor(colors.blue)
    aqua = QColor(colors.aqua)
    teal = QColor(colors.teal)
    olive = QColor(colors.olive)
    green = QColor(colors.green)
    lime = QColor(colors.lime)
    yellow = QColor(colors.yellow)
    orange = QColor(colors.orange)
    red = QColor(colors.red)
    maroon = QColor(colors.maroon)
    fuchsia = QColor(colors.fuchsia)
    purple = QColor(colors.purple)
    black = QColor(colors.black)
    grey = QColor(colors.grey)
    gray = QColor(colors.gray)
    silver = QColor(colors.silver)
    white = QColor(colors.white)